@@ -350,18 +350,18 @@ class XRedisAsync(Singleton):
            
         return conn
 
-    async def lock(self, lock_id, ttl=60, tries=0):
+    def lock(self, lock_id, ttl=60, tries=0):
         try:
             conn = self._get_connection()
             print('获取锁 -> {}'.format(lock_id))
-            return await conn.lock('lock_' + lock_id, blocking_timeout=10, timeout=ttl)
+            return conn.lock('lock_' + lock_id, blocking_timeout=10, timeout=ttl)
         except LockError as error:
             print(str(error))
             return None
         except Exception as e:
             if tries < 3:
                 time.sleep(0.1)
-                return await self.lock(lock_id, ttl, tries + 1)
+                return self.lock(lock_id, ttl, tries + 1)
             else:
                 traceback.print_exc()
 
